package de.intevation.flys.artifacts.model;

import java.math.BigDecimal;

import java.util.List;
import java.util.Iterator;

import de.intevation.flys.backend.SessionHolder;
import de.intevation.flys.model.CrossSection;
import de.intevation.flys.model.Range;
import de.intevation.flys.model.River;

import org.hibernate.Session;
import org.hibernate.Query;

/**
 * Get Cross Sections.
 */
public class CrossSectionFactory {

    /**
     * Get CrossSections for an instantiated River.
     *
     * @param river river object.
     *
     * @return List of Cross Sections of river.
     */
    public static List<CrossSection> getCrossSections(River river) {
        return getCrossSections(river.getName());
    }


    /**
     * Get Cross Sections for a river by name.
     *
     * @param river name of the river of interest.
     *
     * @return List of Cross Sections of river.
     */
    public static List<CrossSection> getCrossSections(String riverName) {
        Session session = SessionHolder.HOLDER.get();
        Query query = session.createQuery(
                "from CrossSection where river.name = :rivername");
        query.setParameter("rivername", riverName);
        return query.list();
    }
}
// vim:set ts=4 sw=4 si et sta sts=4 fenc=utf-8 :

